==> nextcloud-app-bookmarks-1%3A3.2.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/bookmarks/l10n/ru.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Закладки",
    "No file provided for import" : "Не указан файл для импорта",
    "Unsupported file type for import" : "Неподдерживаемый тип файла для импорта",
    "Bookmarks shared by %s" : "Закладки предоставлены пользователем %s ",
    "A Bookmark manager for Nextcloud" : "Менеджер закладок для Nextcloud",
    "This app provides you with a web interface for collecting, organizing and sharing bookmarks to the sites on the web that are precious to you.\nYou can browse and filter your bookmarks via tags, folders and by using the built-in search feature and you can share folders with other users and groups as well as create public links for them.\nAlso, in order to access your bookmarks anywhere, it also allows you to synchronize with third-party clients via a built-in REST API -- be it in your browsers or on your phone.\nCheck out the third-party clients listed here: https://github.com/nextcloud/bookmarks#third-party-clients\n\nRequirements:\n - PHP v7.2+\n - PHP extensions:\n   - intl: *\n   - mbstring: *\n - Nextcloud v17+" : "Это приложение предоставляет веб-интерфейс для сбора и организации закладок веб-сайтов.\nПриложение позволяет просматривать и отбирать для показа закладки по меткам и папкам, а также обладает встроенной функцией поиска.\nПриложение поддерживает REST API, который позволяет получить доступ к закладкам и выполнять синхронизацию с использованием сторонних приложений-клиентов.\nСписок совместимых приложений приведён на этой странице: https://github.com/nextcloud/bookmarks#third-party-clients\n\nТребования:\n - PHP версии 7.2 и старше;\n - Расширения PHP :\n   - gmp: любой версии;\n   - intl: любой версии;\n   - mbstring: любой версии;\n- Nextcloud версии 17 или старше.",
    "Select bookmark" : "Выберите закладки",
    "Details" : "Подробнее",
    "Rename" : "Переименовать",
    "Move" : "Переместить",
    "Delete" : "Удалить",
    "Enter bookmark title" : "Введите заголовок закладки",
    "Save" : "Сохранить",
    "No bookmarks here" : "Здесь нет закладок",
    "Try changing your query or add some using the button on the left." : "Попробуйте изменить ваш запрос или добавьте при помощи кнопки слева.",
    "Select one or more tags" : "Выберите одну или больше меток",
    "New bookmark" : "Новая закладка",
    "New folder" : "Новая папка",
    "Grid view" : "Вид сеткой",
    "List view" : "Вид списком",
    "Move selection" : "Переместить выбранное",
    "Delete selection" : "Удалить выбранное",
    "Open all selected" : "Открыть выбранные",
    "Select all visible" : "Выбрать все видимые",
    "Cancel selection" : "Отменить выбор",
    "Selected {folders} folders and {bookmarks} bookmarks" : "Выделено {folders} папок и {bookmarks} закладок",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Выделена %n закладка","Выделено %n закладок","Выделено %n закладок","Выделено %n закладок"],
    "_Selected %n folder_::_Selected %n folders_" : ["Выделена %n папка","Выделено %n папок","Выделено %n папок","Выделено %n папок"],
    "Enter a link" : "Введите ссылку",
    "Create" : "Создать",
    "Cancel" : "Отмена",
    "Enter folder title" : "Введите название папки",
    "Select folder" : "Выделить папку",
    "Shared by {user}" : "Опубликовано пользователем {user} ",
    "Shared privately" : "Опубликованно для закрытого списка пользователей",
    "Public" : "Общедоступный",
    "Root folder" : "Корневая папка",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Перемещаем %n папку и некоторые закладки","Перемещаем %n папок и некоторые закладки","Перемещаем %n папок и некоторые закладки","Перемещаем %n папок и некоторые закладки"],
    "_Moving %n folder_::_Moving %n folders_" : ["Перемещаем %n папку","Перемещаем %n папок","Перемещаем %n папок","Перемещаем %n папок"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Перемещаем %n закладку","Перемещаем %n закладок","Перемещаем %n закладок","Перемещаем %n закладок"],
    "New Bookmark" : "Новая закладка",
    "All Bookmarks" : "Все закладки",
    "Recent Bookmarks" : "Последние закладки",
    "Untagged" : "Без меток",
    "{used} bookmarks of {available} available" : "{used} закладок из {available} возможных",
    "Import" : "Импортировать",
    "Export" : "Экспортировать",
    "Sorting" : "Сортировка",
    "Recently added" : "Недавно добавленные",
    "Alphabetically" : "В алфавитном порядке",
    "Most visited" : "Самый посещаемые",
    "Last modified" : "В порядке изменения",
    "RSS Feed" : "RSS-лента",
    "This is an RSS feed of the current result set with access restricted to you." : "Это лента в формате RSS к текущему результату, доступ к которой есть только у вас.",
    "Clear data" : "Очистить данные",
    "Permanently remove all bookmarks from your account. There is no going back!" : "Перманентно удалить все закладки из вашего аккаунта. Их будет не вернуть!",
    "Delete all bookmarks" : "Удалить все закладки",
    "Bookmarklet" : "Приложение для панели закладок",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage" : "Перетащите это в закладки вашего браузера и кликните на него, чтобы быстро добавить вебстраницу в закладки",
    "Add to {instanceName}" : "Добавить в {instanceName}",
    "Also check out the collection of client apps that integrate with this app: " : "Так же попробуйте коллекцию клиентских приложений, которые могут интегрировать с этим приложением",
    "Client apps" : "Клиентские приложения",
    "Do you really want to delete all your bookmarks?" : "Вы действительно хотите удалить все ваши закладки?",
    "URL" : "URL",
    "Creation date" : "Дата создания",
    "Tags" : "Метки",
    "Select tags are create new ones" : "Выберите метки или создайте новые",
    "Notes" : "Заметки",
    "Sharing" : "Общий доступ",
    "{time} ago" : "{time} назад",
    "Owner" : "Владелец",
    "Select a user or group" : "Выберите пользователя или группу",
    "Share link" : "Предоставление общего доступа по ссылке",
    "Copy link" : "Скопировать ссылку",
    "Copy RSS feed" : "Скопировать RSS-ленту",
    "Delete link" : "Удалить ссылку",
    "Create public link" : "Создать общедоступную ссылку",
    "Allow editing" : "Разрешить редактирование",
    "Allow sharing" : "Разрешить совместное использование",
    "Remove share" : "Закрыть общий доступ",
    "Link copied" : "Ссылка скопирована",
    "RSS feed copied" : "RSS-лента скопирована",
    "Select" : "Пометить",
    "Previews" : "Предварительный просмотр",
    "In order to display real screenshots of your bookmarked websites, Bookmarks can use a third-party service to generate those." : "Чтобы отобразить действительные скриншоты сайтов в ваших закладках, Bookmarks может использовать внешние сервисы для их генерации",
    "Screeenly" : "Screenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "Вы можете либо зарегистрироваться бесплатно на screenly.com или настроить свой сервер.",
    "Screeenly API URL" : "Ссылка на Screenly API",
    "Screeenly API key" : "API-ключ Screeenly",
    "Privacy" : "Приватность",
    "Bookmarks will try to access web pages that you add to automatically add information about them." : "Bookmarks будет пытаться получить доступ к веб-страницам, которые вы добавили, чтобы автоматически добавить информацию о них.",
    "Enable accessing and collecting information from the web pages you add" : "Включить доступ и сбор информации с веб-страниц, добавляемых вами",
    "Performance" : "Производительность",
    "In an installation with  a lot of users it may be useful to restrict the number of bookmarks per account." : "В установке с множеством пользователей может быть полезно ограничить возможное количество закладок на аккаунт.",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Максимально допустимое количество закладок для аккаунта (0 для безлимита, он же по-умолчанию)",
    "Failed to load settings" : "Не удалось загрузить настройки",
    "Failed to save settings" : "Не удалось сохранить настройки",
    "Add a bookmark" : "Добавить закладку",
    "This URL is already bookmarked! Overwrite?" : "Эта ссылка уже в закладках! Перезаписать?",
    "Title" : "Название",
    "Link" : "Ссылка",
    "Enter bookmark URL" : "Введите URL закладки",
    "Folder" : "Каталог",
    "Root Folder" : "Корневая папка",
    "Failed to find existing bookmark" : "Не удалось найти существующую закладку",
    "Failed to create bookmark" : "Не удалось создать закладку",
    "Failed to save bookmark" : "Не удалось сохранить закладку",
    "Failed to move bookmark" : "Не удалось переместить закладку",
    "Failed to delete bookmark" : "Не удалось удалить закладку",
    "Failed to load tags" : "Не удалось загрузить метки",
    "Failed to load folders" : "Не удалось загрузить папки",
    "Failed to delete folder" : "Не удалось удалить папку",
    "Failed to create folder" : "Не удалось создать папку",
    "Failed to move parts of selection" : "Не удалось переместить часть выделенных объектов",
    "Failed to delete parts of selection" : "Не удалось удалить часть выделенных объектов",
    "Failed to fetch bookmarks." : "Не удалось извлечь закладки.",
    "Failed to change setting" : "Не удалось изменить настройки",
    "Failed to load setting {key}" : "Не удалось загрузить настройку {key}",
    "Failed to update share {shareId}" : "Не удалось обновить общий ресурс {shareId}",
    "Failed to delete share {shareId}" : "Не удалось удалить общий ресурс {shareId}",
    "Bookmarks feed" : "Лента закладок"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");

==> nextcloud-app-bookmarks-1%3A3.4.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/bookmarks/l10n/ru.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Закладки",
    "You bookmarked \"%s\"" : "Вы создали закладку \"%s\"",
    "%1$s bookmarked \"%2$s\"" : "%1$s создал закладку \"%2$s\"",
    "Someone bookmarked \"%s\"" : "Кто-то создал закладку \"%s\"",
    "You deleted \"%s\"" : "Вы удалили \"%s\"",
    "Someone deleted \"%s\"" : "Кто-то удалил \"%s\"",
    "You created folder \"%s\"" : "Вы создали папку \"%s\"",
    "%1$s created folder \"%2$s\"" : "%1$s создал папку \"%2$s\"",
    "Someone created folder \"%s\"" : "Кто-то создал папку \"%s\"",
    "You moved folder \"%s\"" : "Вы переместили папку \"%s\"",
    "%1$s moved folder \"%2$s\"" : "%1$s переместил папку \"%2$s\"",
    "Someone moved folder \"%s\"" : "Кто-то переместил папку \"%s\"",
    "You deleted folder \"%s\"" : "Вы удалили папку \"%s\"",
    "%1$s deleted folder \"%2$s\"" : "%1$s удалил папку \"%2$s\"",
    "Someone deleted folder \"%s\"" : "Кто-то удалил папку \"%s\"",
    "You shared folder \"%1$s\" with %2$s" : "Вы открыли доступ к папке \"%1$s\" для %2$s",
    "You shared folder \"%s\" with someone" : "Вы открыли доступ к папке \"%s\" для всех",
    "%1$s shared folder \"%2$s\" with you" : "%1$s открыл доступ к папке \"%2$s\" для вас",
    "Someone shared folder \"%s\" with you" : "Кто-то открыл доступ к папке \"%s\" для вас",
    "You unshared folder \"%1$s\" with %2$s" : "Вы закрыли доступ к папке \"%1$s\" для %2$s",
    "You unshared folder \"%s\" with someone" : "Вы закрыли доступ к папке \"%s\" для всех",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s закрыл доступ к папке \"%2$s\" для вас",
    "Someone unshared folder \"%s\" with you" : "Кто-то закрыл доступ к папке \"%s\" для вас",
    "No file provided for import" : "Не указан файл для импорта",
    "Unsupported file type for import" : "Неподдерживаемый тип файла для импорта",
    "Bookmarks shared by %s" : "Закладки предоставлены пользователем %s ",
    "A Bookmark manager for Nextcloud" : "Менеджер закладок для Nextcloud",
    "Select bookmark" : "Выберите закладки",
    "Details" : "Подробнее",
    "Rename" : "Переименовать",
    "Move" : "Переместить",
    "Delete" : "Удалить",
    "Select one or more tags" : "Выберите одну или больше меток",
    "New" : "Новая",
    "New bookmark" : "Новая закладка",
    "New folder" : "Новая папка",
    "Grid view" : "Вид сеткой",
    "List view" : "Вид списком",
    "Move selection" : "Переместить выбранное",
    "Delete selection" : "Удалить выбранное",
    "Open all selected" : "Открыть выбранные",
    "Select all" : "Выбрать все",
    "Cancel selection" : "Отменить выбор",
    "Selected {folders} folders and {bookmarks} bookmarks" : "Выделено {folders} папок и {bookmarks} закладок",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Выделена %n закладка","Выделено %n закладок","Выделено %n закладок","Выделено %n закладок"],
    "_Selected %n folder_::_Selected %n folders_" : ["Выделена %n папка","Выделено %n папок","Выделено %n папок","Выделено %n папок"],
    "Enter a link" : "Введите ссылку",
    "Select folder" : "Выделить папку",
    "Enter folder title" : "Введите название папки",
    "Shared by {user}" : "Опубликовано пользователем {user} ",
    "Root folder" : "Корневая папка",
    "Cancel" : "Отмена",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Перемещаем %n папку и некоторые закладки","Перемещаем %n папок и некоторые закладки","Перемещаем %n папок и некоторые закладки","Перемещаем %n папок и некоторые закладки"],
    "_Moving %n folder_::_Moving %n folders_" : ["Перемещаем %n папку","Перемещаем %n папок","Перемещаем %n папок","Перемещаем %n папок"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Перемещаем %n закладку","Перемещаем %n закладок","Перемещаем %n закладок","Перемещаем %n закладок"],
    "All bookmarks" : "Все закладки",
    "Recent" : "Недавние",
    "Untagged" : "Без меток",
    "{used} bookmarks of {available} available" : "{used} закладок из {available} возможных",
    "No bookmarks here" : "Здесь нет закладок",
    "Add a bookmark" : "Добавить закладку",
    "Import" : "Импортировать",
    "Export" : "Экспортировать",
    "Sorting" : "Сортировка",
    "Recently added" : "Недавно добавленные",
    "Alphabetically" : "В алфавитном порядке",
    "Most visited" : "Самый посещаемые",
    "Last modified" : "В порядке изменения",
    "Custom order" : "Настраиваемая сортировка",
    "Client apps" : "Клиентские приложения",
    "Also check out the collection of client apps that integrate with this app: " : "Так же попробуйте коллекцию клиентских приложений, которые могут интегрировать с этим приложением",
    "Bookmarklet" : "Приложение для панели закладок",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage" : "Перетащите это в закладки вашего браузера и кликните на него, чтобы быстро добавить вебстраницу в закладки",
    "Add to {instanceName}" : "Добавить в {instanceName}",
    "Clear data" : "Очистить данные",
    "Delete all bookmarks" : "Удалить все закладки",
    "Do you really want to delete all your bookmarks?" : "Вы действительно хотите удалить все ваши закладки?",
    "Title" : "Название",
    "Link" : "Ссылка",
    "Creation date" : "Дата создания",
    "Tags" : "Метки",
    "Attachments" : "Вложения",
    "Notes" : "Заметки",
    "{time} ago" : "{time} назад",
    "Owner" : "Владелец",
    "Sharing" : "Общий доступ",
    "Select a user or group" : "Выберите пользователя или группу",
    "Share link" : "Предоставление общего доступа по ссылке",
    "Copy link" : "Скопировать ссылку",
    "Copy RSS feed" : "Скопировать RSS-ленту",
    "Delete link" : "Удалить ссылку",
    "Create public link" : "Создать общедоступную ссылку",
    "Allow editing" : "Разрешить редактирование",
    "Allow sharing" : "Разрешить совместное использование",
    "Remove share" : "Закрыть общий доступ",
    "Link copied" : "Ссылка скопирована",
    "RSS feed copied" : "RSS-лента скопирована",
    "Select" : "Пометить",
    "Previews" : "Предварительный просмотр",
    "In order to display real screenshots of your bookmarked websites, Bookmarks can use third-party services to generate previews." : "Для того, чтобы показать реальный вид сайтов в ваших закладках, приложение \"Закладки\" может использовать сторонние сервисы для создания изображения",
    "Screeenly" : "Screenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "Вы можете либо зарегистрироваться бесплатно на screenly.com или настроить свой сервер.",
    "Screeenly API URL" : "Ссылка на Screenly API",
    "Screeenly API key" : "API-ключ Screeenly",
    "Privacy" : "Приватность",
    "Bookmarks will try to access web pages that you add to automatically add information about them." : "Bookmarks будет пытаться получить доступ к веб-страницам, которые вы добавили, чтобы автоматически добавить информацию о них.",
    "Enable accessing and collecting information from the web pages you add" : "Включить доступ и сбор информации с веб-страниц, добавляемых вами",
    "Performance" : "Производительность",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Максимально допустимое количество закладок для аккаунта (0 для безлимита, он же по-умолчанию)",
    "Failed to load settings" : "Не удалось загрузить настройки",
    "Failed to save settings" : "Не удалось сохранить настройки",
    "This URL is already bookmarked! Overwrite?" : "Эта ссылка уже в закладках! Перезаписать?",
    "Enter bookmark title" : "Введите заголовок закладки",
    "Enter bookmark URL" : "Введите URL закладки",
    "Folder" : "Каталог",
    "Root Folder" : "Корневая папка",
    "Save" : "Сохранить",
    "Failed to find existing bookmark" : "Не удалось найти существующую закладку",
    "Failed to create bookmark" : "Не удалось создать закладку",
    "Failed to save bookmark" : "Не удалось сохранить закладку",
    "Failed to move bookmark" : "Не удалось переместить закладку",
    "Failed to delete bookmark" : "Не удалось удалить закладку",
    "Failed to load tags" : "Не удалось загрузить метки",
    "Failed to load folders" : "Не удалось загрузить папки",
    "Failed to delete folder" : "Не удалось удалить папку",
    "Failed to create folder" : "Не удалось создать папку",
    "Failed to fetch bookmarks." : "Не удалось извлечь закладки.",
    "Failed to change setting" : "Не удалось изменить настройки",
    "Failed to load setting {key}" : "Не удалось загрузить настройку {key}",
    "Failed to update share {shareId}" : "Не удалось обновить общий ресурс {shareId}",
    "Failed to delete share {shareId}" : "Не удалось удалить общий ресурс {shareId}",
    "Bookmarks feed" : "Лента закладок"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
